pytest-vts
===
Automatic recorder for http stubbed
`pytest(s) <http://pytest.org/latest/>`_ using
`responses <https://github.com/getsentry/responses>`_ library. VTS
stands for Video Tests System and has been inspired from
`VHS <https://en.wikipedia.org/wiki/Videotape_format_war>`_.

* `Documentation <https://github.com/bhodorog/pytest-vts/blob/master/README.md>`_
* `Changelog <https://github.com/bhodorog/pytest-vts/blob/master/CHANGELOG>`_
* `Github Page <https://github.com/bhodorog/pytest-vts>`_
* `Issue Tracking <https://github.com/bhodorog/pytest-vts/issues>`_
